aboutsummaryrefslogtreecommitdiff
path: root/tests/neg/t7278.scala
diff options
context:
space:
mode:
Diffstat (limited to 'tests/neg/t7278.scala')
-rw-r--r--tests/neg/t7278.scala6
1 files changed, 3 insertions, 3 deletions
diff --git a/tests/neg/t7278.scala b/tests/neg/t7278.scala
index 9a8292409..7aafbb76f 100644
--- a/tests/neg/t7278.scala
+++ b/tests/neg/t7278.scala
@@ -8,13 +8,13 @@ object Test {
// should not compile (?)
// martin says "I'd argue about that"
// martin retracts his statement: this should not compile
- type EE[+X <: EC] = X#E
- type EE2[+X <: EC] = X#E // repeat to get error count to 2
+ type EE[+X <: EC] = X#E // error: X is not a legal path;
+ type EE2[+X <: EC] = X#E // error: X is not a legal path; repeat to get error count to 2
def fail1(): Unit = {
val b = new B
var x1: EE[A] = null
- var x2: EE[B] = new b.E // error: found: B#E, required: A#E
+ var x2: EE[B] = new b.E // old-error: found: B#E, required: A#E
// x1 = x2 // gives a prior type error: B#E, required: A#E, masked to get at the real thing.
}